@@ -4,7 +4,7 @@ import os
 from functools import partial
 from multiprocessing.pool import Pool, ThreadPool
 
-from commmons import linear_sample, get_filesize_in_bytes, get_prefixed_logger
+from commmons import linear_sample, get_filesize_in_bytes, with_prefix
 
 from vripper.download.gdlwrapper import get_images_from_gallery
 from vripper.download.imagedownloader import download_image
@@ -97,7 +97,7 @@ def _delete_invalid_files(pathmap, vparams):
             continue
 
         should_delete = False
-        image_logger = get_prefixed_logger(logger, filename)
+        image_logger = with_prefix(logger, filename)
         filesize = get_filesize_in_bytes(path)
 
         if filesize > vparams.max_filesize or filesize < vparams.min_filesize:
