@@ -1,5 +1,4 @@
-from commmons import html
-from commmons.hash import md5
+from commmons import html_from_url, md5
 
 from vripper.model.vimage import VImage
 from vripper.model.vthread import VThread
@@ -12,7 +11,7 @@ def _get_images(root, index_offset):
 
 
 def v2ph_init(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     # id may contain filesystem-unsafe characters such as the question mark
     hashed_id = md5(url.split("/album/")[-1].split(".")[0].split("?")[0])
